@@ -10,10 +10,12 @@ def getScriptPath():
 
 def DebugLog(msg):
    if os.environ.has_key('DEBUG'):
-      print str(msg)
+      print unicode(msg).encode('utf-8')
 
-def DebugFile(msg):
+def DebugFile(msg, filename=''):
+   if not filename:
+      filename = 'debug.log'
    if os.environ.has_key('DEBUG'):
-      f = open('debug.log', 'a')
-      f.write(str(msg)+"\n")
+      f = open(filename, 'a')
+      f.write(unicode(msg).encode('utf-8'))
       f.close()
