@@ -228,7 +228,7 @@ class AddRideDlg(QtGui.QDialog):
       if not arrivee:
          raise RuntimeError("Gare d'arrivée non renseignée")
 
-      c = self.db.execute("SELECT ligne FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % depart)
+      c = self.db.execute('SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % depart)
       lignesD=[]
       for row in c:
          lignesD.append(row[0])
@@ -237,7 +237,7 @@ class AddRideDlg(QtGui.QDialog):
          DebugLog("Gare '%s' inconnue"%depart)
          raise RuntimeError("Gare '%s' inconnue"%depart)
 
-      c = self.db.execute("SELECT ligne FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % arrivee)
+      c = self.db.execute('SELECT ligne FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid' % arrivee)
 
       lignesA=[]
       for row in c:
@@ -260,7 +260,7 @@ class AddRideDlg(QtGui.QDialog):
 
       DebugLog(str(lignesA))
 
-      req="SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (depart, ligne)
+      req='SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid AND ligne="%s"' % (depart, ligne)
       DebugLog(req)
       c = self.db.execute(req)
 
