@@ -21,7 +21,6 @@ class RideView(QtGui.QWidget):
       self.connect(self.model, QtCore.SIGNAL("info"), self.SetInfo)
 
       self.timer = QtCore.QTimer()
-      self.timer.setSingleShot(True)
       self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.Refresh)
 
       self.menuTimer = QtCore.QTimer()
@@ -200,11 +199,9 @@ class RideView(QtGui.QWidget):
       QtGui.QDesktopServices.openUrl( self.model.getUrl() )
 
    def Animate(self, variant):
-      #DebugLog("RideView::Animate %d"%variant.toSize().height())
       self.progress.setFixedHeight(variant.toSize().height())
 
    def AnimateFinished(self):
-      DebugLog("RideView::AnimateFinished")
       size = self.progress.size()
       if size.height()==0:
          self.progress.hide()
@@ -259,10 +256,8 @@ class RideView(QtGui.QWidget):
          self.ShowInfo()
 
    def ShowInfo(self):
-      DebugLog("RideView::ShowInfo")
       size = self.progress.size()
       if not self.progress.isVisible():
-         DebugLog("not is Visible")
          self.progress.show()
          self.animate.setStartValue( size )
          self.animate.setEndValue( QtCore.QSize(size.width(), 96) )
