@@ -25,6 +25,7 @@ class TrainTrainView(QtGui.QMainWindow):
       self.setMaximumSize(QtCore.QSize(width, width))
       self.setMinimumSize(QtCore.QSize(height, width))
       self.iconsPath = os.path.join(os.path.dirname(getScriptPath()), 'icons')
+      self.updateCpt = 0
 
       try:
          self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
@@ -43,21 +44,14 @@ class TrainTrainView(QtGui.QMainWindow):
       self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.Refresh)
 
       self.CreateAppLayouts()
-      self.ReInit()
+      
+      self.connect(self.model, QtCore.SIGNAL("initialized"), self.PrepareView)
+      self.model.connect(self, QtCore.SIGNAL('InitDatas'), self.model.InitDatas)
+      self.emit(QtCore.SIGNAL('InitDatas'))
 
    def IconPath(self, str):
       return os.path.join(self.iconsPath, str)
 
-   def ReInit(self):
-      DebugLog("TrainTrainView::ReInit")
-
-      self.updateCpt=0
-      for view in self.views.values():
-         self.RemoveView(view)
-      self.model.InitDatas()
-      self.PrepareView()
-      self.SetLoading(True)
-
    def Settings(self):
       dlg = SettingsDlg()
       dlg.exec_()
@@ -65,12 +59,12 @@ class TrainTrainView(QtGui.QMainWindow):
       self.timer.setInterval(self.model.ttConf.refreshRateSec()*1000)
 
    def AddRide(self):
-      dlg = AddRideDlg(self.model.garesConf)
+      dlg = AddRideDlg(self.model.garesConf, self.tabW.currentIndex())
       dlg.exec_()
       ride = dlg.added
       if ride:
-         rideModel = self.model.CreateAndAddRide(ride)
-         self.AppendRideView(rideModel)
+         rideModel = self.model.CreateAndAddRide(ride, True)
+         self.AddRideView(rideModel, ride.sens)
 
    def AddRideSimple(self):
       dlg = AddRideDlg()
@@ -79,32 +73,41 @@ class TrainTrainView(QtGui.QMainWindow):
       if ride:
          ride.id='simple'
          rideModel = self.model.CreateAndAddRide(ride, False)
-         self.SetRideViewSimple(rideModel)
+         self.AddRideView(rideModel, 2)
 
-   def SetRideViewSimple(self, rideModel):
+   def AddRideView(self, rideModel, sens):
       view = RideView(rideModel, self)
+      view.Refresh()
       self.views[rideModel.id] = view
-      self.vLayoutU.addWidget( view )
-      view.Busy()
+      if sens==0:
+         self.layoutAller.addWidget( view )
 
-   def AppendRideView(self, rideModel):
-      view = RideView(rideModel, self)
-      self.views[rideModel.id] = view
-      self.vLayout.addWidget( view )
-      view.Busy()
+      elif sens==1:
+         self.layoutRetour.addWidget( view )
+
+      elif sens==2:
+         self.layoutSimple.addWidget( view )
 
    def PrepareView(self):
       DebugLog("TrainTrainView::PrepareView")
       for rideModel in self.model.GetRidesModel():
-         self.AppendRideView(rideModel)
+         self.AddRideView(rideModel, rideModel.sens)
 
    def RemoveView(self, view):
       DebugLog("TrainTrainView::RemoveView(%s)"%view.model.id)
-      self.model.RemoveRideModel(view.model)
-      self.vLayout.removeWidget(view)
+      if view.model.id!='simple':
+         self.model.RemoveRideModel(view.model)
+      self.layoutAller.removeWidget(view)
       del self.views[view.model.id]
       view.setParent(None)
 
+   def GetLayout(self, layout, align=None):
+      layout.setSpacing(0)
+      layout.setMargin(0)
+      if align:
+         layout.setAlignment(align)
+      return layout
+
    def CreateAppLayouts(self):
       DebugLog("TrainTrainView::CreateAppLayouts")
 
@@ -137,42 +140,46 @@ class TrainTrainView(QtGui.QMainWindow):
       file.addAction(settings)
       file.addAction(about)
 
-      self.vLayout = QtGui.QVBoxLayout()
-      self.vLayout.setSpacing(0)
-      self.vLayout.setMargin(0)
-      self.vLayout.setAlignment(Qt.AlignTop)
-
-      self.tLayout = QtGui.QVBoxLayout()
-      self.tLayout.setSpacing(0)
-      self.tLayout.setMargin(0)
-      self.tLayout.addLayout(self.vLayout)
+      self.layoutAller = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
+      layoutAller = self.GetLayout(QtGui.QVBoxLayout())
+      layoutAller.addLayout(self.layoutAller)
       addButton = QtGui.QPushButton('Ajouter un trajet')
       addButton.clicked.connect(self.AddRide)
-#      addButton.setStyleSheet('background-color:#2684DB; color: #fff; ')
 
-      self.tLayout.addWidget(addButton)
-      self.scrollArea = self.CreateScrollWidget(self.tLayout)
+      layoutAller.addWidget(addButton)
+      addButton.setStyleSheet('background-color:#2684DB; color: #fff; ')
 
-      self.vLayoutU = QtGui.QVBoxLayout()
-      self.vLayoutU.setSpacing(0)
-      self.vLayoutU.setMargin(0)
-      self.vLayoutU.setAlignment(Qt.AlignTop)
+      self.layoutRetour = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
+      layoutRetour = self.GetLayout(QtGui.QVBoxLayout())
+      layoutRetour.addLayout(self.layoutRetour)
+      addRetourButton = QtGui.QPushButton('Ajouter un trajet retour')
+      addRetourButton.clicked.connect(self.AddRide)
+      layoutRetour.addWidget(addRetourButton)
 
+      self.allerArea = self.CreateScrollWidget(layoutAller)
+      self.retourArea = self.CreateScrollWidget(layoutRetour)
+
+      self.layoutSimple = self.GetLayout(QtGui.QVBoxLayout(), Qt.AlignTop)
       addButtonU = QtGui.QPushButton('Voir un trajet simple')
       addButtonU.clicked.connect(self.AddRideSimple)
-      self.vLayoutU.addWidget(addButtonU)
+      self.layoutSimple.addWidget(addButtonU)
 
-      self.scrollAreaU = self.CreateScrollWidget(self.vLayoutU)
+      self.scrollAreaU = self.CreateScrollWidget(self.layoutSimple)
 
       self.tabW = QtGui.QTabWidget()
       self.tabW.setTabPosition(QtGui.QTabWidget.East)
 
       rotate = QtGui.QTransform().rotate(-90)
-      self.iconFav = QtGui.QIcon( QtGui.QPixmap(self.IconPath('mestrainsfav.png')).transformed(rotate) )
+      self.iconAller = QtGui.QIcon( QtGui.QPixmap(self.IconPath('aller.png')).transformed(rotate) )
+      self.iconRetour = QtGui.QIcon( QtGui.QPixmap(self.IconPath('retour.png')).transformed(rotate) )
       self.iconSim = QtGui.QIcon( QtGui.QPixmap(self.IconPath('mestrains.png')).transformed(rotate) )
+      self.iconAdd = QtGui.QIcon( QtGui.QPixmap(self.IconPath('add48.png')).transformed(rotate) )
 
-      self.tabW.addTab(self.scrollArea, self.iconFav, '')
+      self.tabW.addTab(self.allerArea, self.iconAller, '')
+      self.tabW.addTab(self.retourArea, self.iconRetour, '')
       self.tabW.addTab(self.scrollAreaU, self.iconSim, '')
+      self.tabW.setTabEnabled(3, False)
+
       self.tabW.setIconSize( QtCore.QSize(48, 48) )
       self.tabW.setStyleSheet(' \
          QTabBar::tab { \
@@ -184,9 +191,8 @@ class TrainTrainView(QtGui.QMainWindow):
               background: #2684DB; \
 /*              background: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0, stop: 0 #194F97, stop: 1.0 #2684DB);*/ \
           } ')
-      
+
       self.setCentralWidget(self.tabW)
-#      self.setCentralWidget(self.scrollArea)
 
       self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
       self.connect(QtGui.QApplication.desktop(), QtCore.SIGNAL('resized(int)'), self.Resized)
